Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/payments/__init__.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/payments/__init__.py	(revision 11947)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/payments/__init__.py	(revision 11949)
@@ -2,6 +2,6 @@
 """
 # Make this a package.
-from waeup.kofa.payments.container import PaymentsContainer
-from waeup.kofa.payments.payment import OnlinePayment
+from waeup.ikoba.payments.container import PaymentsContainer
+from waeup.ikoba.payments.payment import OnlinePayment
 
 __all__ = [
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/payments/catalog.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/payments/catalog.py	(revision 11947)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/payments/catalog.py	(revision 11949)
@@ -19,6 +19,6 @@
 """
 import grok
-from waeup.kofa.interfaces import IUniversity
-from waeup.kofa.payments.interfaces import IPayment
+from waeup.ikoba.interfaces import IUniversity
+from waeup.ikoba.payments.interfaces import IPayment
 
 class PaymentIndexes(grok.Indexes):
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/payments/container.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/payments/container.py	(revision 11947)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/payments/container.py	(revision 11949)
@@ -21,6 +21,6 @@
 import grok
 from grok import index
-from waeup.kofa.payments.interfaces import IPaymentsContainer
-from waeup.kofa.utils.helpers import attrs_to_fields
+from waeup.ikoba.payments.interfaces import IPaymentsContainer
+from waeup.ikoba.utils.helpers import attrs_to_fields
 
 class PaymentsContainer(grok.Container):
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/payments/payment.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/payments/payment.py	(revision 11947)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/payments/payment.py	(revision 11949)
@@ -25,11 +25,11 @@
 from zope.component import getUtility
 from zope.i18n import translate
-from waeup.kofa.interfaces import IKofaUtils
-from waeup.kofa.interfaces import MessageFactory as _
-from waeup.kofa.payments.interfaces import (
+from waeup.ikoba.interfaces import IIkobaUtils
+from waeup.ikoba.interfaces import MessageFactory as _
+from waeup.ikoba.payments.interfaces import (
     IPayment, IOnlinePayment,
     payment_states)
-from waeup.kofa.utils.helpers import attrs_to_fields, get_current_principal
-from waeup.kofa.utils.logger import Logger
+from waeup.ikoba.utils.helpers import attrs_to_fields, get_current_principal
+from waeup.ikoba.utils.logger import Logger
 
 class Payment(grok.Container, Logger):
@@ -40,5 +40,5 @@
     grok.baseclass()
 
-    logger_name = 'waeup.kofa.${sitename}.payments'
+    logger_name = 'waeup.ikoba.${sitename}.payments'
     logger_filename = 'payments.log'
     logger_format_str = '"%(asctime)s","%(user)s",%(message)s'
@@ -62,11 +62,11 @@
     @property
     def category(self):
-        utils = getUtility(IKofaUtils)
+        utils = getUtility(IIkobaUtils)
         return utils.PAYMENT_CATEGORIES.get(self.p_category, None)
 
     @property
     def display_item(self):
-        kofa_utils = getUtility(IKofaUtils)
-        return kofa_utils.getPaymentItem(self)
+        ikoba_utils = getUtility(IIkobaUtils)
+        return ikoba_utils.getPaymentItem(self)
 
 class OnlinePayment(Payment):
@@ -95,6 +95,6 @@
                 usertitle = user.title
         r_desc = _('Payment approved by ${a}', mapping = {'a': usertitle})
-        portal_language = getUtility(IKofaUtils).PORTAL_LANGUAGE
-        self.r_desc = translate(r_desc, 'waeup.kofa',
+        portal_language = getUtility(IIkobaUtils).PORTAL_LANGUAGE
+        self.r_desc = translate(r_desc, 'waeup.ikoba',
             target_language=portal_language)
         self.payment_date = datetime.utcnow()
Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/payments/tests.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/payments/tests.py	(revision 11947)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/payments/tests.py	(revision 11949)
@@ -20,9 +20,9 @@
 """
 from zope.interface.verify import verifyClass, verifyObject
-from waeup.kofa.payments.interfaces import (
+from waeup.ikoba.payments.interfaces import (
     IPaymentsContainer, IOnlinePayment)
-from waeup.kofa.payments.container import PaymentsContainer
-from waeup.kofa.payments.payment import OnlinePayment
-from waeup.kofa.testing import (FunctionalLayer, FunctionalTestCase)
+from waeup.ikoba.payments.container import PaymentsContainer
+from waeup.ikoba.payments.payment import OnlinePayment
+from waeup.ikoba.testing import (FunctionalLayer, FunctionalTestCase)
 
 class PaymentsContainerTestCase(FunctionalTestCase):

Index: main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/payments/interfaces.py
===================================================================
--- main/waeup.kofa/branches/henrik-regista/src/waeup/kofa/payments/interfaces.py	(revision 11947)
+++ main/waeup.kofa/branches/henrik-regista/src/waeup/ikoba/payments/interfaces.py	(revision 11949)
@@ -18,10 +18,10 @@
 from zope.interface import Attribute
 from zope import schema
-from waeup.kofa.interfaces import (
-    IKofaObject, SimpleKofaVocabulary, application_sessions_vocab,
+from waeup.ikoba.interfaces import (
+    IIkobaObject, SimpleIkobaVocabulary, application_sessions_vocab,
     ContextualDictSourceFactoryBase)
-from waeup.kofa.interfaces import MessageFactory as _
+from waeup.ikoba.interfaces import MessageFactory as _
 
-payment_states = SimpleKofaVocabulary(
+payment_states = SimpleIkobaVocabulary(
     (_('Not yet paid'),'unpaid'),
     (_('Paid'),'paid'),
@@ -33,13 +33,13 @@
 
     """
     #: name of dict to deliver from kofa utils.
     DICT_NAME = 'PAYMENT_CATEGORIES'
 
-class IPaymentsContainer(IKofaObject):
+class IPaymentsContainer(IIkobaObject):
     """A container for all kind of payment objects.
 
     """
 
-class IPayment(IKofaObject):
+class IPayment(IIkobaObject):
     """A base representation of payments.
 
@@ -33,13 +33,13 @@
 
     """
-    #: name of dict to deliver from kofa utils.
+    #: name of dict to deliver from ikoba utils.
     DICT_NAME = 'PAYMENT_CATEGORIES'
 